{% load fleetpings_versioned_static %}

<link rel="stylesheet" href="{% fleetpings_static 'fleetpings/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% fleetpings_static 'fleetpings/css/fleetpings.min.css' %}">
