@media all {
    .aa-fleetpings-header-addition {
        display: block;
    }

    .aa-fleetpings-pingtext {
        position: sticky;
        top: 1rem;
    }

    .aa-fleetpings-footer {
        border-top: 1px solid rgb(236 240 241);
        font-size: 85%;
        margin-top: 1rem;
        padding-top: 1rem;
    }

    .template-dark-mode .aa-fleetpings-footer {
        border-color: rgb(70 69 69);
    }
}
